@@ -286,8 +286,28 @@ G_STMT_START {						\
  * @buf: a #GstBuffer.
  *
  * Increases the refcount of the given buffer by one.
+ *
+ * Note that the refcount affects the writeability
+ * of @buf and its metadata, see gst_buffer_is_writable() and
+ * gst_buffer_is_metadata_writable(). It is
+ * important to note that keeping additional references to
+ * GstBuffer instances can potentially increase the number
+ * of memcpy operations in a pipeline.
+ *
+ * Returns: @buf
  */
-#define		gst_buffer_ref(buf)		GST_BUFFER_CAST (gst_mini_object_ref (GST_MINI_OBJECT (buf)))
+#ifdef _FOOL_GTK_DOC_
+G_INLINE_FUNC GstBuffer * gst_buffer_ref (GstBuffer * buf);
+#endif
+
+static inline GstBuffer *
+gst_buffer_ref (GstBuffer * buf)
+{
+  /* not using a macro here because gcc-4.1 will complain
+   * if the return value isn't used (because of the cast) */
+  return (GstBuffer *) gst_mini_object_ref (GST_MINI_OBJECT (buf));
+}
+
 /**
  * gst_buffer_unref:
  * @buf: a #GstBuffer.
@@ -314,7 +334,7 @@ G_STMT_START {						\
  * Tests if you can safely write data into a buffer's data array or validly
  * modify the caps and timestamp metadata. Metadata in a GstBuffer is always
  * writable, but it is only safe to change it when there is only one owner
- * of the buffer - ie, the buffer is 1. 
+ * of the buffer - ie, the refcount is 1. 
  */
 #define		gst_buffer_is_writable(buf)	gst_mini_object_is_writable (GST_MINI_OBJECT (buf))
 /**
