@@ -1,8 +1,9 @@
 /* GStreamer
  * Copyright (C) 1999,2000 Erik Walthinsen <omega@cse.ogi.edu>
  *                    2000 Wim Taymans <wtay@chello.be>
+ *                    2005 Wim Taymans <wim@fluendo.com>
  *
- * gstclock.h: Header for clock subsystem
+ * gstsystemclock.h: A clock implementation based on system time
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -39,19 +40,27 @@ G_BEGIN_DECLS
 typedef struct _GstSystemClock GstSystemClock;
 typedef struct _GstSystemClockClass GstSystemClockClass;
 
+/**
+ * GstSystemClock:
+ * @clock: The parent clock
+ *
+ * The default implementation of a #GstClock that uses the system time.
+ */
 struct _GstSystemClock {
   GstClock 	 clock;
 
-  GMutex *	 mutex;
-  GCond *	 cond;
+  /*< private >*/
+  GThread	*thread;	/* thread for async notify */
+  gboolean 	 stopping;
 
-  GST_OBJECT_PADDING
+  gpointer _gst_reserved[GST_PADDING];
 };
 
 struct _GstSystemClockClass {
   GstClockClass  parent_class;
 
-  GST_CLASS_PADDING
+  /*< private >*/
+  gpointer _gst_reserved[GST_PADDING];
 };
 
 GType 			gst_system_clock_get_type 	(void);
