@@ -25,12 +25,10 @@
 #  include "config.h"
 #endif
 
-#include <gst/gst.h>
 #include <gst/controller/gstcontroller.h>
 
-#include "gst/gst-i18n-app.h"
+#include "tools.h"
 
-#include <stdlib.h>
 #include <string.h>
 #include <locale.h>
 #include <glib/gprintf.h>
@@ -914,7 +912,7 @@ print_element_list (gboolean print_all)
     gst_plugin_feature_list_free (orig_features);
   }
 
-  gst_plugin_list_free (plugins);
+  gst_plugin_list_free (orig_plugins);
 
   g_print ("\nTotal plugins: %d\nTotal features: %d\n",
       plugincount, featurecount);
@@ -1098,6 +1096,7 @@ main (int argc, char *argv[])
   GOptionEntry options[] = {
     {"print-all", 'a', 0, G_OPTION_ARG_NONE, &print_all,
         N_("Print all elements"), NULL},
+    GST_TOOLS_GOPTION_VERSION,
     {NULL}
   };
   GOptionContext *ctx;
@@ -1109,7 +1108,7 @@ main (int argc, char *argv[])
   textdomain (GETTEXT_PACKAGE);
 #endif
 
-  ctx = g_option_context_new ("gst-inspect");
+  ctx = g_option_context_new ("[ELEMENT-NAME | PLUGIN-NAME]");
   g_option_context_add_main_entries (ctx, options, GETTEXT_PACKAGE);
   g_option_context_add_group (ctx, gst_init_get_option_group ());
   if (!g_option_context_parse (ctx, &argc, &argv, &err)) {
@@ -1118,6 +1117,8 @@ main (int argc, char *argv[])
   }
   g_option_context_free (ctx);
 
+  gst_tools_print_version ("gst-inspect");
+
   if (print_all && argc > 2) {
     g_print ("-a requires no extra arguments\n");
     return 1;
